pub fn init()Expand description
Initialize the global tracing subscriber.
Reads the RUST_LOG environment variable for filtering and falls back to
info. Safe to call more than once; subsequent calls are ignored.
pub fn init()Initialize the global tracing subscriber.
Reads the RUST_LOG environment variable for filtering and falls back to
info. Safe to call more than once; subsequent calls are ignored.